//CListView.cpp: Implementation of the CListView class

#include "CListView.h"

CListView::CListView(QWidget* parent) : QListView(parent)
{

}

void CListView::keyPressEvent(QKeyEvent *evt)
 {
     //Overriden keypress handler (ignores events from left / right arrow keys).

    if(evt->key()==Qt::Key_Left||evt->key()==Qt::Key_Right||evt->key()==Qt::Key_M)
    {
        evt->ignore();
    }
    else
    {
        QListView::keyPressEvent(evt); //default handler
    }

 }


